Tutorials
=========

sda

Basic AiiDA tutorials:
^^^^^^^^^^^^^^^^^^^^^^
If you are not familiar with the basics of AiiDA yet, you might want to checkout
the `AiiDA youtube tutorials. <https://www.youtube.com/channel/UC-NZvRRQ5VzT2wKE5DM1N3A/playlists>`_
The jupyter notebooks from the tutorials you will find `here <https://github.com/aiidateam/aiida_demos>`__ on github,
where you can also try them out in binder.
Virtual machines for tutorials and tutorial manuals you find `here <http://www.aiida.net/tutorials/>`__.


How calculation plugins work:
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Run inpgen calculation tutorial
"""""""""""""""""""""""""""""""

sorry, not uploaded yet

Run fleur calculation tutorial
""""""""""""""""""""""""""""""
sorry, not uploaded yet

Running workflows:
^^^^^^^^^^^^^^^^^^

Run fleur SCF tutorial
""""""""""""""""""""""
sorry, not uploaded yet

Run fleur eos tutorial
""""""""""""""""""""""
sorry, not uploaded yet

Run fleur bandstructure/dos tutorial
""""""""""""""""""""""""""""""""""""
sorry, not uploaded yet

Data extraction and evaluation:
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

General calculation, workflow
"""""""""""""""""""""""""""""

Total database
""""""""""""""
